/* Copyright (c) Sun Microsystems 2006. All rights reserved.
   This file is part of OpenOffice.org project.
   
   Written by Ramón García Fernández <ramon.garcia.f+openoffice@gmail.com>.
   This work was supported by a Google Summer of Code grant.
*/

/* Component code to interface UNO */

#include <osl/interlck.h>
#include <osl/mutex.hxx>
#include <rtl/uuid.h>
#include <rtl/ustrbuf.hxx>

#include <cppuhelper/factory.hxx>
#include <cppuhelper/implementationentry.hxx>

#include <com/sun/star/lang/XTypeProvider.hpp>
#include "objectbrowser_impl.hxx"

using namespace ::rtl;
using namespace ::com::sun::star;
using namespace ::com::sun::star::uno;

namespace objectbrowser_impl
{

static Sequence< OUString > SAL_CALL getSupportedServiceNames_ObjectBrowserImpl()
{
    Sequence< OUString > names(1);
    names[0] = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.reflection.ObjectBrowserService"));
    return names;
}

static OUString SAL_CALL getImplementationName_ObjectBrowserImpl()
{
    // FIXME: is this a good name?
    return OUString( RTL_CONSTASCII_USTRINGPARAM(
                         "com.sun.star.basic.ObjectBrowser") );
}

OUString SAL_CALL ObjectBrowserImpl::getImplementationName()
    throw (RuntimeException)
{
    return getImplementationName_ObjectBrowserImpl();
}

sal_Bool SAL_CALL ObjectBrowserImpl::supportsService( OUString const & serviceName )
    throw (RuntimeException)
{
    return serviceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM(
                                         "com.sun.star.basic.ObjectBrowserService") );
}

Sequence<OUString> SAL_CALL ObjectBrowserImpl::getSupportedServiceNames()
    throw (RuntimeException)
{
    return getSupportedServiceNames_ObjectBrowserImpl();
}

Reference<XInterface> SAL_CALL create_ObjectBrowserImpl(
    const Reference< XComponentContext > & xContext )
    SAL_THROW( () )
{
    return static_cast< lang::XTypeProvider * >( new ObjectBrowserImpl(xContext) );
}

static struct ::cppu::ImplementationEntry s_component_entries [] =
{
    {
        create_ObjectBrowserImpl, getImplementationName_ObjectBrowserImpl,
        getSupportedServiceNames_ObjectBrowserImpl,
        ::cppu::createSingleComponentFactory,
        0, 0
    },
    { 0, 0, 0, 0, 0, 0 }
};
}

extern "C"
{
void SAL_CALL component_getImplementationEnvironment(
    sal_Char const ** ppEnvTypeName, uno_Environment ** ppEnv )
{
    *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
}
sal_Bool SAL_CALL component_writeInfo(
    lang::XMultiServiceFactory * xMgr, registry::XRegistryKey * xRegistry )
{
    return ::cppu::component_writeInfoHelper(
        xMgr, xRegistry, ::objectbrowser_impl::s_component_entries );
}
void * SAL_CALL component_getFactory(
    sal_Char const * implName, lang::XMultiServiceFactory * xMgr,
    registry::XRegistryKey * xRegistry )
{
    return ::cppu::component_getFactoryHelper(
        implName, xMgr, xRegistry, ::objectbrowser_impl::s_component_entries );
}
}



